@@ -11,7 +11,7 @@ from pydmt.api.one_source_one_target import OneSourceOneTarget
 
 class Installer(OneSourceOneTarget):
     def build(self) -> None:
-        unlink_files(self.target)
+        unlink_files([self.target])
         args = [
             'npm',
             'install',
